# coding: utf-8

"""
    Inventory API

    The Inventory API is used to create and manage inventory, and then to publish and manage this inventory on an eBay marketplace. There are also methods in this API that will convert eligible, active eBay listings into the Inventory API model.  # noqa: E501

    OpenAPI spec version: 1.18.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EnergyEfficiencyLabel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'image_description': 'str',
        'image_url': 'str',
        'product_information_sheet': 'str'
    }

    attribute_map = {
        'image_description': 'imageDescription',
        'image_url': 'imageURL',
        'product_information_sheet': 'productInformationSheet'
    }

    def __init__(self, image_description=None, image_url=None, product_information_sheet=None):  # noqa: E501
        """EnergyEfficiencyLabel - a model defined in Swagger"""  # noqa: E501
        self._image_description = None
        self._image_url = None
        self._product_information_sheet = None
        self.discriminator = None
        if image_description is not None:
            self.image_description = image_description
        if image_url is not None:
            self.image_url = image_url
        if product_information_sheet is not None:
            self.product_information_sheet = product_information_sheet

    @property
    def image_description(self):
        """Gets the image_description of this EnergyEfficiencyLabel.  # noqa: E501

        A brief verbal summary of the information included on the Energy Efficiency Label for an item.<br><br>For example, <i>On a scale of A to G the rating is E.</i>  # noqa: E501

        :return: The image_description of this EnergyEfficiencyLabel.  # noqa: E501
        :rtype: str
        """
        return self._image_description

    @image_description.setter
    def image_description(self, image_description):
        """Sets the image_description of this EnergyEfficiencyLabel.

        A brief verbal summary of the information included on the Energy Efficiency Label for an item.<br><br>For example, <i>On a scale of A to G the rating is E.</i>  # noqa: E501

        :param image_description: The image_description of this EnergyEfficiencyLabel.  # noqa: E501
        :type: str
        """

        self._image_description = image_description

    @property
    def image_url(self):
        """Gets the image_url of this EnergyEfficiencyLabel.  # noqa: E501

        The URL to the Energy Efficiency Label image that is applicable to an item.  # noqa: E501

        :return: The image_url of this EnergyEfficiencyLabel.  # noqa: E501
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url):
        """Sets the image_url of this EnergyEfficiencyLabel.

        The URL to the Energy Efficiency Label image that is applicable to an item.  # noqa: E501

        :param image_url: The image_url of this EnergyEfficiencyLabel.  # noqa: E501
        :type: str
        """

        self._image_url = image_url

    @property
    def product_information_sheet(self):
        """Gets the product_information_sheet of this EnergyEfficiencyLabel.  # noqa: E501

        The URL to the Product Information Sheet that provides complete manufacturer-provided efficiency information about an item.  # noqa: E501

        :return: The product_information_sheet of this EnergyEfficiencyLabel.  # noqa: E501
        :rtype: str
        """
        return self._product_information_sheet

    @product_information_sheet.setter
    def product_information_sheet(self, product_information_sheet):
        """Sets the product_information_sheet of this EnergyEfficiencyLabel.

        The URL to the Product Information Sheet that provides complete manufacturer-provided efficiency information about an item.  # noqa: E501

        :param product_information_sheet: The product_information_sheet of this EnergyEfficiencyLabel.  # noqa: E501
        :type: str
        """

        self._product_information_sheet = product_information_sheet

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EnergyEfficiencyLabel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnergyEfficiencyLabel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
