# coding: utf-8

"""
    Inventory API

    The Inventory API is used to create and manage inventory, and then to publish and manage this inventory on an eBay marketplace. There are also methods in this API that will convert eligible, active eBay listings into the Inventory API model.  # noqa: E501

    OpenAPI spec version: 1.18.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Regulatory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'documents': 'list[Document]',
        'energy_efficiency_label': 'EnergyEfficiencyLabel',
        'hazmat': 'Hazmat',
        'manufacturer': 'Manufacturer',
        'product_safety': 'ProductSafety',
        'repair_score': 'float',
        'responsible_persons': 'list[ResponsiblePerson]'
    }

    attribute_map = {
        'documents': 'documents',
        'energy_efficiency_label': 'energyEfficiencyLabel',
        'hazmat': 'hazmat',
        'manufacturer': 'manufacturer',
        'product_safety': 'productSafety',
        'repair_score': 'repairScore',
        'responsible_persons': 'responsiblePersons'
    }

    def __init__(self, documents=None, energy_efficiency_label=None, hazmat=None, manufacturer=None, product_safety=None, repair_score=None, responsible_persons=None):  # noqa: E501
        """Regulatory - a model defined in Swagger"""  # noqa: E501
        self._documents = None
        self._energy_efficiency_label = None
        self._hazmat = None
        self._manufacturer = None
        self._product_safety = None
        self._repair_score = None
        self._responsible_persons = None
        self.discriminator = None
        if documents is not None:
            self.documents = documents
        if energy_efficiency_label is not None:
            self.energy_efficiency_label = energy_efficiency_label
        if hazmat is not None:
            self.hazmat = hazmat
        if manufacturer is not None:
            self.manufacturer = manufacturer
        if product_safety is not None:
            self.product_safety = product_safety
        if repair_score is not None:
            self.repair_score = repair_score
        if responsible_persons is not None:
            self.responsible_persons = responsible_persons

    @property
    def documents(self):
        """Gets the documents of this Regulatory.  # noqa: E501

        This container provides a collection of regulatory documents associated with the listing.<br><br>For information on removing one or more files from a listing using the <a href= \"/api-docs/sell/inventory/resources/offer/methods/updateOffer\" target=\"_blank\">updateOffer</a>  method, see <a href= \"/api-docs/sell/static/inventory/managing-document-media.html#revise\" target=\"_blank\">Remove documents from listings.</a> .<br><br><span class=\"tablenote\"><b>Note:</b> As a part of General Product Safety Regulation (GPSR) requirements effective on December 13th, 2024, sellers operating in, or shipping to, EU-based countries or Northern Ireland  are conditionally required to provide regulatory document information in their eBay listings. For more information on GPSR, see <a href = \"https://www.ebay.com/sellercenter/resources/general-product-safety-regulation \" target=\"_blank\">General Product Safety Regulation (GPSR)</a>.</span>  # noqa: E501

        :return: The documents of this Regulatory.  # noqa: E501
        :rtype: list[Document]
        """
        return self._documents

    @documents.setter
    def documents(self, documents):
        """Sets the documents of this Regulatory.

        This container provides a collection of regulatory documents associated with the listing.<br><br>For information on removing one or more files from a listing using the <a href= \"/api-docs/sell/inventory/resources/offer/methods/updateOffer\" target=\"_blank\">updateOffer</a>  method, see <a href= \"/api-docs/sell/static/inventory/managing-document-media.html#revise\" target=\"_blank\">Remove documents from listings.</a> .<br><br><span class=\"tablenote\"><b>Note:</b> As a part of General Product Safety Regulation (GPSR) requirements effective on December 13th, 2024, sellers operating in, or shipping to, EU-based countries or Northern Ireland  are conditionally required to provide regulatory document information in their eBay listings. For more information on GPSR, see <a href = \"https://www.ebay.com/sellercenter/resources/general-product-safety-regulation \" target=\"_blank\">General Product Safety Regulation (GPSR)</a>.</span>  # noqa: E501

        :param documents: The documents of this Regulatory.  # noqa: E501
        :type: list[Document]
        """

        self._documents = documents

    @property
    def energy_efficiency_label(self):
        """Gets the energy_efficiency_label of this Regulatory.  # noqa: E501


        :return: The energy_efficiency_label of this Regulatory.  # noqa: E501
        :rtype: EnergyEfficiencyLabel
        """
        return self._energy_efficiency_label

    @energy_efficiency_label.setter
    def energy_efficiency_label(self, energy_efficiency_label):
        """Sets the energy_efficiency_label of this Regulatory.


        :param energy_efficiency_label: The energy_efficiency_label of this Regulatory.  # noqa: E501
        :type: EnergyEfficiencyLabel
        """

        self._energy_efficiency_label = energy_efficiency_label

    @property
    def hazmat(self):
        """Gets the hazmat of this Regulatory.  # noqa: E501


        :return: The hazmat of this Regulatory.  # noqa: E501
        :rtype: Hazmat
        """
        return self._hazmat

    @hazmat.setter
    def hazmat(self, hazmat):
        """Sets the hazmat of this Regulatory.


        :param hazmat: The hazmat of this Regulatory.  # noqa: E501
        :type: Hazmat
        """

        self._hazmat = hazmat

    @property
    def manufacturer(self):
        """Gets the manufacturer of this Regulatory.  # noqa: E501


        :return: The manufacturer of this Regulatory.  # noqa: E501
        :rtype: Manufacturer
        """
        return self._manufacturer

    @manufacturer.setter
    def manufacturer(self, manufacturer):
        """Sets the manufacturer of this Regulatory.


        :param manufacturer: The manufacturer of this Regulatory.  # noqa: E501
        :type: Manufacturer
        """

        self._manufacturer = manufacturer

    @property
    def product_safety(self):
        """Gets the product_safety of this Regulatory.  # noqa: E501


        :return: The product_safety of this Regulatory.  # noqa: E501
        :rtype: ProductSafety
        """
        return self._product_safety

    @product_safety.setter
    def product_safety(self, product_safety):
        """Sets the product_safety of this Regulatory.


        :param product_safety: The product_safety of this Regulatory.  # noqa: E501
        :type: ProductSafety
        """

        self._product_safety = product_safety

    @property
    def repair_score(self):
        """Gets the repair_score of this Regulatory.  # noqa: E501

        This field represents the repair index for the listing.<br><br>The repair index identifies the manufacturer's repair score for a product (i.e., how easy is it to repair the product.) This field is a floating point value between 0.0 (i.e., difficult to repair,) and 10.0 (i.e., easily repaired.)<br><br><span class=\"tablenote\"><b>Note:</b> <code>0</code> should not be used as a default value, as it implies the product is not repairable.</span><br>The format for <b>repairScore</b> is limited to one decimal place. For example:<ul><li><code>7.9</code> and <code>0.0</code> are both valid scores</li><li><code>5.645</code> and <code>2.10</code> are both invalid scores</li></ul><br><span class=\"tablenote\"><b>Note:</b> Repair score is not applicable to all categories. Use the <a href=\"/api-docs/sell/metadata/resources/marketplace/methods/getExtendedProducerResponsibilityPolicies\" target=\"_blank\">getExtendedProducerResponsibilityPolicies</a> method of the <b>Metadata API</b> to see where repair score is applicable.</span>  # noqa: E501

        :return: The repair_score of this Regulatory.  # noqa: E501
        :rtype: float
        """
        return self._repair_score

    @repair_score.setter
    def repair_score(self, repair_score):
        """Sets the repair_score of this Regulatory.

        This field represents the repair index for the listing.<br><br>The repair index identifies the manufacturer's repair score for a product (i.e., how easy is it to repair the product.) This field is a floating point value between 0.0 (i.e., difficult to repair,) and 10.0 (i.e., easily repaired.)<br><br><span class=\"tablenote\"><b>Note:</b> <code>0</code> should not be used as a default value, as it implies the product is not repairable.</span><br>The format for <b>repairScore</b> is limited to one decimal place. For example:<ul><li><code>7.9</code> and <code>0.0</code> are both valid scores</li><li><code>5.645</code> and <code>2.10</code> are both invalid scores</li></ul><br><span class=\"tablenote\"><b>Note:</b> Repair score is not applicable to all categories. Use the <a href=\"/api-docs/sell/metadata/resources/marketplace/methods/getExtendedProducerResponsibilityPolicies\" target=\"_blank\">getExtendedProducerResponsibilityPolicies</a> method of the <b>Metadata API</b> to see where repair score is applicable.</span>  # noqa: E501

        :param repair_score: The repair_score of this Regulatory.  # noqa: E501
        :type: float
        """

        self._repair_score = repair_score

    @property
    def responsible_persons(self):
        """Gets the responsible_persons of this Regulatory.  # noqa: E501

        This container provides information about the EU-based Responsible Persons or entities associated with the listing.<br><br>A maximum of 5 EU Responsible Persons are supported.<br><br><span class=\"tablenote\"><b>Note:</b> As a part of General Product Safety Regulation (GPSR) requirements effective on December 13th, 2024, sellers operating in, or shipping to, EU-based countries or Northern Ireland  are conditionally required to provide regulatory Responsible Persons information in their eBay listings. For more information on GPSR, see <a href = \"https://www.ebay.com/sellercenter/resources/general-product-safety-regulation \" target=\"_blank\">General Product Safety Regulation (GPSR)</a>.</span>  # noqa: E501

        :return: The responsible_persons of this Regulatory.  # noqa: E501
        :rtype: list[ResponsiblePerson]
        """
        return self._responsible_persons

    @responsible_persons.setter
    def responsible_persons(self, responsible_persons):
        """Sets the responsible_persons of this Regulatory.

        This container provides information about the EU-based Responsible Persons or entities associated with the listing.<br><br>A maximum of 5 EU Responsible Persons are supported.<br><br><span class=\"tablenote\"><b>Note:</b> As a part of General Product Safety Regulation (GPSR) requirements effective on December 13th, 2024, sellers operating in, or shipping to, EU-based countries or Northern Ireland  are conditionally required to provide regulatory Responsible Persons information in their eBay listings. For more information on GPSR, see <a href = \"https://www.ebay.com/sellercenter/resources/general-product-safety-regulation \" target=\"_blank\">General Product Safety Regulation (GPSR)</a>.</span>  # noqa: E501

        :param responsible_persons: The responsible_persons of this Regulatory.  # noqa: E501
        :type: list[ResponsiblePerson]
        """

        self._responsible_persons = responsible_persons

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Regulatory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Regulatory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
