# coding: utf-8

# flake8: noqa
"""
    Rate Table API

    This API allows sellers to retrieve and manage their custom shipping rate tables. In addition, this API also provides sellers in mainland China methods to configure split-payouts between two separate payment instruments.  # noqa: E501

    OpenAPI spec version: 2.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from ...sell_account.models.amount import Amount
from ...sell_account.models.error import Error
from ...sell_account.models.error_parameter import ErrorParameter
from ...sell_account.models.payout_instrument import PayoutInstrument
from ...sell_account.models.payout_settings_response import PayoutSettingsResponse
from ...sell_account.models.rate import Rate
from ...sell_account.models.rate_table_details import RateTableDetails
from ...sell_account.models.rate_table_update import RateTableUpdate
from ...sell_account.models.rate_update import RateUpdate
from ...sell_account.models.update_payout_percentage import UpdatePayoutPercentage
from ...sell_account.models.update_payout_percentage_request import UpdatePayoutPercentageRequest
