# coding: utf-8

"""
    Buy Feed API

    The Feed API provides the ability to download TSV_GZIP feed files containing eBay items and an hourly snapshot file for a specific category, date, and marketplace.<br /><br />In addition to the API, there is an open-source Feed SDK written in Java that downloads, combines files into a single file when needed, and unzips the entire feed file. It also lets you specify field filters to curate the items in the file.  # noqa: E501

    OpenAPI spec version: v1.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Access(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'constraints': 'list[FeedTypeConstraint]',
        'feed_type': 'str'
    }

    attribute_map = {
        'constraints': 'constraints',
        'feed_type': 'feedType'
    }

    def __init__(self, constraints=None, feed_type=None):  # noqa: E501
        """Access - a model defined in Swagger"""  # noqa: E501
        self._constraints = None
        self._feed_type = None
        self.discriminator = None
        if constraints is not None:
            self.constraints = constraints
        if feed_type is not None:
            self.feed_type = feed_type

    @property
    def constraints(self):
        """Gets the constraints of this Access.  # noqa: E501

        This array shows the eBay marketplace and eBay L1 categories that the corresponding feed type applies to. If there are no <b>marketplaceId</b> constraints, the application has access to all marketplaces. If there are no <b>categoryId</b> constraints, then the application has access to all categories within the given marketplace.  # noqa: E501

        :return: The constraints of this Access.  # noqa: E501
        :rtype: list[FeedTypeConstraint]
        """
        return self._constraints

    @constraints.setter
    def constraints(self, constraints):
        """Sets the constraints of this Access.

        This array shows the eBay marketplace and eBay L1 categories that the corresponding feed type applies to. If there are no <b>marketplaceId</b> constraints, the application has access to all marketplaces. If there are no <b>categoryId</b> constraints, then the application has access to all categories within the given marketplace.  # noqa: E501

        :param constraints: The constraints of this Access.  # noqa: E501
        :type: list[FeedTypeConstraint]
        """

        self._constraints = constraints

    @property
    def feed_type(self):
        """Gets the feed_type of this Access.  # noqa: E501

        The identifier of the feed type that the application has access to.  # noqa: E501

        :return: The feed_type of this Access.  # noqa: E501
        :rtype: str
        """
        return self._feed_type

    @feed_type.setter
    def feed_type(self, feed_type):
        """Sets the feed_type of this Access.

        The identifier of the feed type that the application has access to.  # noqa: E501

        :param feed_type: The feed_type of this Access.  # noqa: E501
        :type: str
        """

        self._feed_type = feed_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Access, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Access):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
