# coding: utf-8

"""
    Compliance API

    Service for providing information to sellers about their listings being non-compliant, or at risk for becoming non-compliant, against eBay listing policies.  # noqa: E501

    OpenAPI spec version: 1.4.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CorrectiveRecommendations(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'product_recommendation': 'ProductRecommendation',
        'aspect_recommendations': 'list[AspectRecommendations]'
    }

    attribute_map = {
        'product_recommendation': 'productRecommendation',
        'aspect_recommendations': 'aspectRecommendations'
    }

    def __init__(self, product_recommendation=None, aspect_recommendations=None):  # noqa: E501
        """CorrectiveRecommendations - a model defined in Swagger"""  # noqa: E501
        self._product_recommendation = None
        self._aspect_recommendations = None
        self.discriminator = None
        if product_recommendation is not None:
            self.product_recommendation = product_recommendation
        if aspect_recommendations is not None:
            self.aspect_recommendations = aspect_recommendations

    @property
    def product_recommendation(self):
        """Gets the product_recommendation of this CorrectiveRecommendations.  # noqa: E501


        :return: The product_recommendation of this CorrectiveRecommendations.  # noqa: E501
        :rtype: ProductRecommendation
        """
        return self._product_recommendation

    @product_recommendation.setter
    def product_recommendation(self, product_recommendation):
        """Sets the product_recommendation of this CorrectiveRecommendations.


        :param product_recommendation: The product_recommendation of this CorrectiveRecommendations.  # noqa: E501
        :type: ProductRecommendation
        """

        self._product_recommendation = product_recommendation

    @property
    def aspect_recommendations(self):
        """Gets the aspect_recommendations of this CorrectiveRecommendations.  # noqa: E501

        This container is returned for <code>ASPECTS_ADOPTION</code> violations if eBay has found one or more item aspect name-value pairs that may be appropriate for the seller's product. In many cases, the missing or invalid item aspect(s) shown under the corresponding <strong>violationData</strong> array, will also show up under this array with suggested value(s).  # noqa: E501

        :return: The aspect_recommendations of this CorrectiveRecommendations.  # noqa: E501
        :rtype: list[AspectRecommendations]
        """
        return self._aspect_recommendations

    @aspect_recommendations.setter
    def aspect_recommendations(self, aspect_recommendations):
        """Sets the aspect_recommendations of this CorrectiveRecommendations.

        This container is returned for <code>ASPECTS_ADOPTION</code> violations if eBay has found one or more item aspect name-value pairs that may be appropriate for the seller's product. In many cases, the missing or invalid item aspect(s) shown under the corresponding <strong>violationData</strong> array, will also show up under this array with suggested value(s).  # noqa: E501

        :param aspect_recommendations: The aspect_recommendations of this CorrectiveRecommendations.  # noqa: E501
        :type: list[AspectRecommendations]
        """

        self._aspect_recommendations = aspect_recommendations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CorrectiveRecommendations, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CorrectiveRecommendations):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
