# coding: utf-8

# flake8: noqa
"""
    Marketplace Insights API

    <span class=\"tablenote\"><b>Note:</b> This is a <a href=\"/api-docs/static/versioning.html#limited \" target=\"_blank\"> <img src=\"/cms/img/docs/partners-api.svg\" class=\"legend-icon partners-icon\" title=\"Limited Release\"  alt=\"Limited Release\" />(Limited Release)</a> API available only to select developers approved by business units. For information on how to obtain access to this API in production, see the <a href=\"/../api-docs/buy/static/buy-requirements.html\" target=\"_blank\">Buy APIs Requirements</a>.</span>  <p>The Marketplace Insights API provides the ability to search for sold items on eBay by keyword, GTIN, category, and product and returns the of sales history of those items.</p>  # noqa: E501

    OpenAPI spec version: v1_beta.2.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from ...buy_marketplace_insights.models.aspect_distribution import AspectDistribution
from ...buy_marketplace_insights.models.aspect_value_distribution import AspectValueDistribution
from ...buy_marketplace_insights.models.buying_option_distribution import BuyingOptionDistribution
from ...buy_marketplace_insights.models.category import Category
from ...buy_marketplace_insights.models.category_distribution import CategoryDistribution
from ...buy_marketplace_insights.models.condition_distribution import ConditionDistribution
from ...buy_marketplace_insights.models.converted_amount import ConvertedAmount
from ...buy_marketplace_insights.models.error import Error
from ...buy_marketplace_insights.models.error_parameter import ErrorParameter
from ...buy_marketplace_insights.models.image import Image
from ...buy_marketplace_insights.models.item_location import ItemLocation
from ...buy_marketplace_insights.models.item_sales import ItemSales
from ...buy_marketplace_insights.models.refinement import Refinement
from ...buy_marketplace_insights.models.sales_history_paged_collection import SalesHistoryPagedCollection
from ...buy_marketplace_insights.models.seller import Seller
