# coding: utf-8

# flake8: noqa
"""
    Media API

    The <b>Media API</b> lets sellers to create, upload, and retrieve files, including:<ul><li>videos</li><li>documents (for GPSR regulations)</li></ul>  # noqa: E501

    OpenAPI spec version: v1_beta.2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from ...commerce_media.models.create_document_request import CreateDocumentRequest
from ...commerce_media.models.create_document_response import CreateDocumentResponse
from ...commerce_media.models.create_video_request import CreateVideoRequest
from ...commerce_media.models.document_metadata import DocumentMetadata
from ...commerce_media.models.document_response import DocumentResponse
from ...commerce_media.models.error import Error
from ...commerce_media.models.error_parameter import ErrorParameter
from ...commerce_media.models.image import Image
from ...commerce_media.models.input_stream import InputStream
from ...commerce_media.models.moderation import Moderation
from ...commerce_media.models.play import Play
from ...commerce_media.models.video import Video
